@@ -22,7 +22,7 @@ package Class::Base;
 
 use strict;
 
-our $VERSION  = '0.04';
+our $VERSION  = '0.06';
 
 
 #------------------------------------------------------------------------
@@ -48,7 +48,7 @@ sub new {
                       ? $config->{ debug }
               : defined $config->{ DEBUG }
                       ? $config->{ DEBUG }
-                      : ( ${"$class\::DEBUG"} || 0 );
+                      : ( do { local $^W; ${"$class\::DEBUG"} } || 0 );
 
     my $self = bless {
 	_ID    => $config->{ id    } || $config->{ ID    } || $class,
